@@ -243,7 +243,7 @@ def _select_organization() -> QCMinimalOrganization:
 @click.option("--output",
               type=PathParameter(exists=False, file_okay=False, dir_okay=True),
               help="Directory to store results in (defaults to PROJECT/backtests/TIMESTAMP)")
-@click.option("--detach",
+@click.option("--detach", "-d",
               is_flag=True,
               default=False,
               help="Run the backtest in a detached Docker container and return immediately")
@@ -334,12 +334,12 @@ def backtest(project: Path,
     lean_config_manager.configure_data_purchase_limit(lean_config, data_purchase_limit)
 
     cli_config_manager = container.cli_config_manager()
-    engine_image = cli_config_manager.get_engine_image(image)
+    project_config_manager = container.project_config_manager()
 
-    docker_manager = container.docker_manager()
+    project_config = project_config_manager.get_project_config(algorithm_file.parent)
+    engine_image = cli_config_manager.get_engine_image(image or project_config.get("engine-image", None))
 
-    if update or not docker_manager.supports_dotnet_5(engine_image):
-        docker_manager.pull_image(engine_image)
+    container.update_manager().pull_docker_image_if_necessary(engine_image, update)
 
     if not output.exists():
         output.mkdir(parents=True)
@@ -356,7 +356,3 @@ def backtest(project: Path,
                          debugging_method,
                          release,
                          detach)
-
-    if str(engine_image) == DEFAULT_ENGINE_IMAGE and not update:
-        update_manager = container.update_manager()
-        update_manager.warn_if_docker_image_outdated(engine_image)
