@@ -20,7 +20,7 @@ from typing import Any, Dict, Optional
 import click
 
 from lean.click import LeanCommand, PathParameter, ensure_options
-from lean.constants import DEFAULT_ENGINE_IMAGE, GUI_PRODUCT_ID
+from lean.constants import DEFAULT_ENGINE_IMAGE, GUI_PRODUCT_INSTALL_ID
 from lean.container import container
 from lean.models.brokerages.local import all_local_brokerages, local_brokerage_data_feeds, all_local_data_feeds
 from lean.models.brokerages.local.atreyu import AtreyuBrokerage
@@ -244,7 +244,7 @@ def _get_default_value(key: str) -> Optional[Any]:
 @click.option("--output",
               type=PathParameter(exists=False, file_okay=False, dir_okay=True),
               help="Directory to store results in (defaults to PROJECT/live/TIMESTAMP)")
-@click.option("--detach",
+@click.option("--detach", "-d",
               is_flag=True,
               default=False,
               help="Run the live deployment in a detached Docker container and return immediately")
@@ -334,6 +334,10 @@ def _get_default_value(key: str) -> Optional[Any]:
               type=str,
               default=lambda: _get_default_value("binance-api-secret"),
               help="Your Binance API secret")
+@click.option("--binance-use-testnet",
+              type=bool,
+              default=lambda: _get_default_value("binance-use-testnet"),
+              help="Whether the testnet should be used")
 @click.option("--zerodha-api-key",
               type=str,
               default=lambda: _get_default_value("zerodha-api-key"),
@@ -559,6 +563,7 @@ def live(project: Path,
          gdax_use_sandbox: Optional[bool],
          binance_api_key: Optional[str],
          binance_api_secret: Optional[str],
+         binance_use_testnet: Optional[bool],
          zerodha_api_key: Optional[str],
          zerodha_access_token: Optional[str],
          zerodha_product_type: Optional[str],
@@ -643,7 +648,7 @@ def live(project: Path,
 
     if gui:
         module_manager = container.module_manager()
-        module_manager.install_module(GUI_PRODUCT_ID, _get_organization_id(gui_organization, "local GUI"))
+        module_manager.install_module(GUI_PRODUCT_INSTALL_ID, _get_organization_id(gui_organization, "local GUI"))
 
         detach = True
 
@@ -682,8 +687,8 @@ def live(project: Path,
                                                         gdax_passphrase,
                                                         gdax_use_sandbox)
         elif brokerage == BinanceBrokerage.get_name():
-            ensure_options(["binance_api_key", "binance_api_secret"])
-            brokerage_configurer = BinanceBrokerage(binance_api_key, binance_api_secret)
+            ensure_options(["binance_api_key", "binance_api_secret", "binance_use_testnet"])
+            brokerage_configurer = BinanceBrokerage(binance_api_key, binance_api_secret, binance_use_testnet)
         elif brokerage == ZerodhaBrokerage.get_name():
             ensure_options(["zerodha_api_key",
                             "zerodha_access_token",
@@ -789,8 +794,10 @@ def live(project: Path,
                                                                             gdax_passphrase,
                                                                             gdax_use_sandbox))
         elif data_feed == BinanceDataFeed.get_name():
-            ensure_options(["binance_api_key", "binance_api_secret"])
-            data_feed_configurer = BinanceDataFeed(BinanceBrokerage(binance_api_key, binance_api_secret))
+            ensure_options(["binance_api_key", "binance_api_secret", "binance_use_testnet"])
+            data_feed_configurer = BinanceDataFeed(BinanceBrokerage(binance_api_key,
+                                                                    binance_api_secret,
+                                                                    binance_use_testnet))
         elif data_feed == ZerodhaDataFeed.get_name():
             ensure_options(["zerodha_api_key",
                             "zerodha_access_token",
@@ -891,13 +898,13 @@ def live(project: Path,
 
     _raise_for_missing_properties(lean_config, environment_name, lean_config_manager.get_lean_config_path())
 
+    project_config_manager = container.project_config_manager()
     cli_config_manager = container.cli_config_manager()
-    engine_image = cli_config_manager.get_engine_image(image)
 
-    docker_manager = container.docker_manager()
+    project_config = project_config_manager.get_project_config(algorithm_file.parent)
+    engine_image = cli_config_manager.get_engine_image(image or project_config.get("engine-image", None))
 
-    if update or not docker_manager.supports_dotnet_5(engine_image) or not docker_manager.image_installed(engine_image):
-        docker_manager.pull_image(engine_image)
+    container.update_manager().pull_docker_image_if_necessary(engine_image, update)
 
     _start_iqconnect_if_necessary(lean_config, environment_name)
 
@@ -917,7 +924,3 @@ def live(project: Path,
     if gui:
         logger = container.logger()
         logger.info(f"You can monitor the status of the live deployment in the GUI")
-
-    if str(engine_image) == DEFAULT_ENGINE_IMAGE and not update:
-        update_manager = container.update_manager()
-        update_manager.warn_if_docker_image_outdated(engine_image)
