@@ -53,7 +53,7 @@ def _find_project_directory(backtest_file: Path) -> Optional[Path]:
               type=PathParameter(exists=False, file_okay=True, dir_okay=False),
               default=lambda: Path.cwd() / "report.html",
               help="Path where the generated report is stored as HTML (defaults to ./report.html)")
-@click.option("--detach",
+@click.option("--detach", "-d",
               is_flag=True,
               default=False,
               help="Run the report creator in a detached Docker container and return immediately")
@@ -219,14 +219,18 @@ def report(backtest_results: Optional[Path],
                                            read_only=True))
 
     cli_config_manager = container.cli_config_manager()
-    engine_image = cli_config_manager.get_engine_image(image)
+    engine_image_override = image
 
-    docker_manager = container.docker_manager()
+    if engine_image_override is None and project_directory is not None:
+        project_config_manager = container.project_config_manager()
+        project_config = project_config_manager.get_project_config(project_directory)
+        engine_image_override = project_config.get("engine-image", None)
 
-    if update or not docker_manager.supports_dotnet_5(engine_image):
-        docker_manager.pull_image(engine_image)
+    engine_image = cli_config_manager.get_engine_image(engine_image_override)
 
-    success = docker_manager.run_image(engine_image, **run_options)
+    container.update_manager().pull_docker_image_if_necessary(engine_image, update)
+
+    success = container.docker_manager().run_image(engine_image, **run_options)
     if not success:
         raise RuntimeError(
             "Something went wrong while running the LEAN Report Creator, see the logs above for more information")
@@ -241,7 +245,3 @@ def report(backtest_results: Optional[Path],
         return
 
     logger.info(f"Successfully generated report to '{report_destination}'")
-
-    if str(engine_image) == DEFAULT_ENGINE_IMAGE and not update:
-        update_manager = container.update_manager()
-        update_manager.warn_if_docker_image_outdated(engine_image)
