@@ -13,15 +13,16 @@
 
 import re
 from pathlib import Path
-from typing import Any, Dict, Optional
+from typing import Any, Dict, Optional, List
 
 import json5
 
 from lean.components.cloud.module_manager import ModuleManager
 from lean.components.config.cli_config_manager import CLIConfigManager
 from lean.components.config.project_config_manager import ProjectConfigManager
+from lean.components.config.storage import Storage
 from lean.components.util.logger import Logger
-from lean.constants import DEFAULT_LEAN_CONFIG_FILE_NAME, GUI_PRODUCT_ID
+from lean.constants import DEFAULT_LEAN_CONFIG_FILE_NAME, GUI_PRODUCT_INSTALL_ID
 from lean.models.config import DebuggingMethod
 from lean.models.errors import MoreInfoError
 
@@ -33,19 +34,23 @@ class LeanConfigManager:
                  logger: Logger,
                  cli_config_manager: CLIConfigManager,
                  project_config_manager: ProjectConfigManager,
-                 module_manager: ModuleManager) -> None:
+                 module_manager: ModuleManager,
+                 cache_storage: Storage) -> None:
         """Creates a new LeanConfigManager instance.
 
         :param logger: the logger to log messages with
         :param cli_config_manager: the CLIConfigManager instance to use when retrieving credentials
         :param project_config_manager: the ProjectConfigManager instance to use when retrieving project parameters
         :param module_manager: the ModuleManager to use
+        :param cache_storage: the Storage instance to store known Lean config paths in
         """
         self._logger = logger
         self._cli_config_manager = cli_config_manager
         self._project_config_manager = project_config_manager
         self._module_manager = module_manager
+        self._cache_storage = cache_storage
         self._default_path = None
+        self._lean_config_path = None
 
     def get_lean_config_path(self) -> Path:
         """Returns the path to the closest Lean config file.
@@ -60,12 +65,17 @@ class LeanConfigManager:
         if self._default_path is not None:
             return self._default_path
 
+        if self._lean_config_path is not None:
+            return self._lean_config_path
+
         # Recurse upwards in the directory tree until we find a Lean config file
         current_dir = Path.cwd()
         while True:
             target_file = current_dir / DEFAULT_LEAN_CONFIG_FILE_NAME
             if target_file.exists():
-                return target_file
+                self._lean_config_path = target_file
+                self.store_known_lean_config_path(self._lean_config_path)
+                return self._lean_config_path
 
             # If the parent directory is the same as the current directory we can't go up any more
             if current_dir.parent == current_dir:
@@ -79,8 +89,31 @@ class LeanConfigManager:
 
         :param path: the path to the Lean config file to return in future calls to get_lean_config_path()
         """
+        self.store_known_lean_config_path(path)
         self._default_path = path
 
+    def get_known_lean_config_paths(self) -> List[Path]:
+        """Returns the known Lean config file paths.
+
+        :return: a list of paths to Lean config files that were used in the past
+        """
+        lean_config_paths = self._cache_storage.get("known-lean-config-paths", [])
+        lean_config_paths = [Path(p) for p in lean_config_paths]
+        lean_config_paths = [p for p in lean_config_paths if p.is_file()]
+
+        self._cache_storage.set("known-lean-config-paths", [str(p) for p in lean_config_paths])
+
+        return lean_config_paths
+
+    def store_known_lean_config_path(self, path: Path) -> None:
+        """Caches a path as being a known Lean configuration file path.
+
+        :param path: the path to the Lean configuration file
+        """
+        lean_config_paths = set(self._cache_storage.get("known-lean-config-paths", []))
+        lean_config_paths.add(str(path))
+        self._cache_storage.set("known-lean-config-paths", list(lean_config_paths))
+
     def get_cli_root_directory(self) -> Path:
         """Returns the path to the directory containing the Lean config file.
 
@@ -198,16 +231,23 @@ class LeanConfigManager:
             config["debugging"] = False
             config["debugging-method"] = "LocalCmdline"
 
-        config["job-user-id"] = self._cli_config_manager.user_id.get_value(default="0")
-        config["api-access-token"] = self._cli_config_manager.api_token.get_value(default="")
-        config["job-project-id"] = self._project_config_manager.get_local_id(algorithm_file.parent)
+        # The following key -> value pairs are added to the config unless they are already set by the user
+        config_defaults = {
+            "job-user-id": self._cli_config_manager.user_id.get_value(default="0"),
+            "api-access-token": self._cli_config_manager.api_token.get_value(default=""),
+            "job-project-id": self._project_config_manager.get_local_id(algorithm_file.parent),
 
-        config["ib-host"] = "127.0.0.1"
-        config["ib-port"] = "4002"
-        config["ib-tws-dir"] = "/usr/local/ibgateway"
-        config["ib-version"] = "984"
+            "ib-host": "127.0.0.1",
+            "ib-port": "4002",
+            "ib-tws-dir": "/root/Jts",
+            "ib-version": "985",
 
-        config["iqfeed-host"] = "host.docker.internal"
+            "iqfeed-host": "host.docker.internal"
+        }
+
+        for key, value in config_defaults.items():
+            if config.get(key, "") == "":
+                config[key] = value
 
         if algorithm_file.name.endswith(".py"):
             config["algorithm-type-name"] = algorithm_file.name.split(".")[0]
@@ -222,7 +262,7 @@ class LeanConfigManager:
         project_config = self._project_config_manager.get_project_config(algorithm_file.parent)
         config["parameters"] = project_config.get("parameters", {})
 
-        if self._module_manager.is_module_installed(GUI_PRODUCT_ID):
+        if self._module_manager.is_module_installed(GUI_PRODUCT_INSTALL_ID):
             config["messaging-handler"] = "QuantConnect.GUI.LocalMessagingHandler"
 
         return config
