@@ -33,7 +33,7 @@ from docker.types import Mount
 from lean.components.util.logger import Logger
 from lean.components.util.platform_manager import PlatformManager
 from lean.components.util.temp_manager import TempManager
-from lean.constants import DEFAULT_ENGINE_IMAGE, DOTNET_5_IMAGE_CREATED_TIMESTAMP, SITE_PACKAGES_VOLUME_LIMIT, \
+from lean.constants import SITE_PACKAGES_VOLUME_LIMIT, \
     DOCKER_NETWORK
 from lean.models.docker import DockerImage
 from lean.models.errors import MoreInfoError
@@ -296,14 +296,19 @@ class DockerManager:
         docker_client = self._get_docker_client()
         return any(str(image) in x.tags for x in docker_client.images.list())
 
-    def get_local_digest(self, image: DockerImage) -> str:
+    def get_local_digest(self, image: DockerImage) -> Optional[str]:
         """Returns the digest of a locally installed image.
 
         :param image: the local image to get the digest of
-        :return: the digest of the local image
+        :return: the digest of the local image, or None if the digest does not exist
         """
         img = self._get_docker_client().images.get(str(image))
-        return img.attrs["RepoDigests"][0].split("@")[1]
+
+        repo_digests = img.attrs["RepoDigests"]
+        if len(repo_digests) == 0:
+            return None
+
+        return repo_digests[0].split("@")[1]
 
     def get_remote_digest(self, image: DockerImage) -> str:
         """Returns the digest of a remote image.
@@ -377,17 +382,23 @@ class DockerManager:
 
         return None
 
-    def show_logs(self, container_name: str) -> None:
-        """Shows the logs in the terminal, streaming them live if the container is still running.
+    def show_logs(self, container_name: str, follow: bool = False) -> None:
+        """Shows the logs of a Docker container in the terminal.
 
         :param container_name: the name of the container to show the logs of
+        :param follow: whether the logs should be streamed in real-time if the container is running (defaults to False)
         """
         if self.get_container_by_name(container_name) is None:
             return
 
         # We cannot use the Docker Python SDK to get live logs consistently
         # Since the logs command is the same on Windows, macOS and Linux we can safely use a system call
-        subprocess.run(["docker", "logs", "-f", container_name])
+        command = ["docker", "logs"]
+        if follow:
+            command.append("-f")
+        command.append(container_name)
+
+        subprocess.run(command)
 
     def is_missing_permission(self) -> bool:
         """Returns whether we cannot connect to the Docker client because of a permissions issue.
@@ -402,20 +413,6 @@ class DockerManager:
             return "Permission denied" in str(exception)
         return False
 
-    def supports_dotnet_5(self, image: DockerImage) -> bool:
-        """Returns whether an image supports .NET 5 based on its creation date.
-
-        :return: True if we think the image supports .NET 5, False if not or if the tag is not installed
-        """
-        # We can't make guesses on non-default images
-        if str(image) != DEFAULT_ENGINE_IMAGE and str(image) != DEFAULT_ENGINE_IMAGE:
-            return True
-
-        for img in self._get_docker_client().images.list():
-            if str(image) in img.tags:
-                return isoparse(img.attrs["Created"]) >= DOTNET_5_IMAGE_CREATED_TIMESTAMP
-        return False
-
     def _get_docker_client(self) -> docker.DockerClient:
         """Creates a DockerClient instance.
 
